==> magics++_2.22.7.dfsg.1.orig.tar.xz: magics++-2.22.7.dfsg.1/src/libMagWrapper/MagRequest.h <==
/*! \file MagRequest.h
    \brief Definition of the Template class MagRequest.
    
    Magics Team - ECMWF 2010
    
    Started: Tue 24-Aug-2010
    
    Changes:
    
*/

#ifndef XMagRequest_H
#define XMagRequest_H

#include "magics.h"

namespace magics {

class MagParam {
public:
	MagParam() {}
	~MagParam() {}
 
	virtual operator double() const { return dvalue_; }
	virtual operator string() const { return svalue_;}
	virtual operator int() const { return ivalue_; }
	
	virtual MagParam& operator=(int i) { ivalue_ = i; cout << "set int" << ivalue_ << endl; return *this;}
	virtual MagParam& operator=(string s) { svalue_ = s; cout << "set string" << svalue_ << endl; return *this;}
	virtual MagParam& operator=(double d) { dvalue_ = d; cout << "set double" << dvalue_ << endl; return *this; }

protected:
	string svalue_;
    int ivalue_;
    double dvalue_;
};


class MagRequest {

public:
	MagRequest() {}
	virtual ~MagRequest() {}

	
	virtual string getVerb() const = 0;
	virtual MagParam& operator()(const string& name) const =0;
	virtual MagParam& operator()(const string& name, int i) const =0;
	virtual int countValues(const string& name) const =0;

	virtual MagRequest& getSubRequest(const string&) =0;
    virtual operator bool () const =0;
    virtual void advance () =0;
	virtual int countParameters() =0;
	virtual int countValues(const string&) =0;
	virtual string getParameter(int) =0;
	virtual void print() =0;
	virtual void read(const string&) =0;
	virtual MagRequest& justOneRequest() =0;
	
protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
	 virtual void print(ostream&) const {}
	 

private:
    //! Copy constructor - No copy allowed
	//MagRequest(const MagRequest&);
    //! Overloaded << operator to copy - No copy allowed
	//MagRequest& operator=(const MagRequest&);

// -- Friends
    //! Overloaded << operator to call print().
	friend ostream& operator<<(ostream& s,const MagRequest& p)
		{ p.print(s); return s; }

};

} // end namespace
#endif

==> magics++_2.26.2.orig.tar.xz: magics++-2.26.2/src/libMagWrapper/MagRequest.h <==
/*! \file MagRequest.h
    \brief Definition of the Template class MagRequest.
    
    Magics Team - ECMWF 2010
    
    Started: Tue 24-Aug-2010
    
    Changes:
    
*/

#ifndef XMagRequest_H
#define XMagRequest_H

#include "magics.h"

namespace magics {

class MagParam {
public:
	MagParam() {}
	~MagParam() {}
 
	virtual operator double() const { return dvalue_; }
	virtual operator string() const { return svalue_;}
	virtual operator int() const { return ivalue_; }
	virtual operator long int() const { return lvalue_; }
	
	virtual MagParam& operator=(int i) { ivalue_ = i; cout << "set int" << ivalue_ << endl; return *this;}
	virtual MagParam& operator=(string s) { svalue_ = s; cout << "set string" << svalue_ << endl; return *this;}
	virtual MagParam& operator=(double d) { dvalue_ = d; cout << "set double" << dvalue_ << endl; return *this; }
	virtual MagParam& operator=(long int i) { ivalue_ = i; cout << "set long int" << ivalue_ << endl; return *this; }
protected:
	string svalue_;
    int ivalue_;
    int lvalue_;
    double dvalue_;
};


class MagRequest {

public:
	MagRequest() {}
	virtual ~MagRequest() {}

	
	virtual string getVerb() const = 0;
	virtual MagParam& operator()(const string& name) const =0;
	virtual MagParam& operator()(const string& name, int i) const =0;
	virtual int countValues(const string& name) const =0;

	virtual MagRequest& getSubRequest(const string&) =0;
    virtual operator bool () const =0;
    virtual void advance () =0;
	virtual int countParameters() =0;
	virtual int countValues(const string&) =0;
	virtual string getParameter(int) =0;
	virtual void print() =0;
	virtual void read(const string&) =0;
	virtual MagRequest& justOneRequest() =0;
	
protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
	 virtual void print(ostream&) const {}
	 

private:
    //! Copy constructor - No copy allowed
	//MagRequest(const MagRequest&);
    //! Overloaded << operator to copy - No copy allowed
	//MagRequest& operator=(const MagRequest&);

// -- Friends
    //! Overloaded << operator to call print().
	friend ostream& operator<<(ostream& s,const MagRequest& p)
		{ p.print(s); return s; }

};

} // end namespace
#endif
